==> rheolef_6.5.orig.tar.gz: rheolef-6.5/doc/pexamples/navier_stokes_cavity.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
GEODIR="${TOP_SRCDIR}/nfem/ptst"
SBINDIR="../../nfem/sbin"
BINDIR="../../nfem/pbin"
NPROC_MAX=${NPROC_MAX-"2"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0
#echo "      not yet (skipped)"

run "$SBINDIR/mkgeo_grid_2d -v4 -t 10 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-10.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-10.field.gz"

loop_mpirun "./navier_stokes_cavity mesh-2d-10 10 0 0 >/dev/null 2>/dev/null &&
gzip -dc < mesh-2d-10.field.gz 2>/dev/null | $BINDIR/field - -field -round 1e-7 2>/dev/null | diff $SRCDIR/navier_stokes_cavity-10-10.field - >/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-10.field.gz mesh-2d-10.geo"

exit $status

==> rheolef_6.6.orig.tar.gz: rheolef-6.6/doc/pexamples/navier_stokes_cavity.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
GEODIR="${TOP_SRCDIR}/nfem/ptst"
SBINDIR="../../nfem/sbin"
BINDIR="../../nfem/pbin"
NPROC_MAX=${NPROC_MAX-"2"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test x"${QD_EXT}" != x""; then
  echo "      not yet (skiped when QD lib is active)"
  exit 0
fi

status=0

run "$SBINDIR/mkgeo_grid_2d -v4 -t 10 2>/dev/null | $BINDIR/geo -upgrade - > mesh-2d-10.geo 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-10.field.gz"

loop_mpirun "./navier_stokes_cavity mesh-2d-10 10 0 0 >/dev/null 2>/dev/null &&
gzip -dc < mesh-2d-10.field.gz 2>/dev/null | $BINDIR/field - -field -round 1e-7 2>/dev/null | diff $SRCDIR/navier_stokes_cavity-10-10.field - >/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-10.field.gz mesh-2d-10.geo"

exit $status
